@@ -3,15 +3,14 @@
 
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
-#ifndef URIHANDLER_H
-#define URIHANDLER_H
+#pragma once
 
 #include "calendarsupport_export.h"
 
 class QString;
 
-namespace CalendarSupport {
-
+namespace CalendarSupport
+{
 /** URI handler. */
 class CALENDARSUPPORT_EXPORT UriHandler
 {
@@ -25,5 +24,3 @@ public:
 };
 
 } // namespace
-
-#endif
